@@ -2,13 +2,15 @@
 # (probably in a test; this may not match the DTD exactly, but we
 # should document just how it differs).
 
-# Data taken from http://www.w3.org/TR/html401/index/elements.html
-# and http://www.w3.org/community/webed/wiki/HTML/New_HTML5_Elements
-# for html5_tags.
+"""
+Data taken from https://www.w3.org/TR/html401/index/elements.html
+and https://www.w3.org/community/webed/wiki/HTML/New_HTML5_Elements
+for html5_tags.
+"""
 
 empty_tags = frozenset([
     'area', 'base', 'basefont', 'br', 'col', 'frame', 'hr',
-    'img', 'input', 'isindex', 'link', 'meta', 'param'])
+    'img', 'input', 'isindex', 'link', 'meta', 'param', 'source', 'track'])
 
 deprecated_tags = frozenset([
     'applet', 'basefont', 'center', 'dir', 'font', 'isindex',
@@ -21,6 +23,8 @@ link_attrs = frozenset([
     'usemap',
     # Not standard:
     'dynsrc', 'lowsrc',
+    # HTML5 formaction
+    'formaction'
     ])
 
 # Not in the HTML 4 spec:
